package cn.com.infosec.asn1;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.SimpleTimeZone;

public class DERUTCTime extends ASN1Object {
   String time;

   public static DERUTCTime getInstance(Object obj) {
      if (obj != null && !(obj instanceof DERUTCTime)) {
         if (obj instanceof ASN1OctetString) {
            return new DERUTCTime(((ASN1OctetString)obj).getOctets());
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (DERUTCTime)obj;
      }
   }

   public static DERUTCTime getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(obj.getObject());
   }

   public DERUTCTime(String time) {
      DERUTCTime var10000 = this;
      super();
      this.time = time;

      try {
         var10000.getDate();
      } catch (ParseException var2) {
         throw new IllegalArgumentException("invalid date string: " + var2.getMessage());
      }

   }

   public DERUTCTime(Date time) {
      SimpleDateFormat var10001 = new SimpleDateFormat("yyMMddHHmmss'Z'");
      var10001.setTimeZone(new SimpleTimeZone(0, "Z"));
      this.time = var10001.format(time);
   }

   DERUTCTime(byte[] bytes) {
      int var2;
      char[] var3 = new char[var2 = bytes.length];

      for(int var4 = 0; var4 != var2; ++var4) {
         var3[var4] = (char)(bytes[var4] & 255);
      }

      String var5;
      var5 = new String.<init>(var3);
      this.time = var5;
   }

   private byte[] getOctets() {
      char[] var3;
      byte[] var1 = new byte[(var3 = this.time.toCharArray()).length];

      for(int var2 = 0; var2 != var3.length; ++var2) {
         var1[var2] = (byte)var3[var2];
      }

      return var1;
   }

   public Date getDate() {
      return (new SimpleDateFormat("yyMMddHHmmssz")).parse(this.getTime());
   }

   public Date getAdjustedDate() {
      SimpleDateFormat var10000 = new SimpleDateFormat("yyyyMMddHHmmssz");
      var10000.setTimeZone(new SimpleTimeZone(0, "Z"));
      return var10000.parse(this.getAdjustedTime());
   }

   public String getTime() {
      if (this.time.indexOf(45) < 0 && this.time.indexOf(43) < 0) {
         return this.time.length() == 11 ? this.time.substring(0, 10) + "00GMT+00:00" : this.time.substring(0, 12) + "GMT+00:00";
      } else {
         int var1;
         if ((var1 = this.time.indexOf(45)) < 0) {
            var1 = this.time.indexOf(43);
         }

         String var2;
         if (var1 == (var2 = this.time).length() - 3) {
            var2 = var2 + "00";
         }

         return var1 == 10 ? var2.substring(0, 10) + "00GMT" + var2.substring(10, 13) + ":" + var2.substring(13, 15) : var2.substring(0, 12) + "GMT" + var2.substring(12, 15) + ":" + var2.substring(15, 17);
      }
   }

   public String getAdjustedTime() {
      String var1;
      return (var1 = this.getTime()).charAt(0) < '5' ? "20" + var1 : "19" + var1;
   }

   void encode(DEROutputStream out) {
      out.writeEncoded(23, this.getOctets());
   }

   boolean asn1Equals(DERObject o) {
      return !(o instanceof DERUTCTime) ? false : this.time.equals(((DERUTCTime)o).time);
   }

   public int hashCode() {
      return this.time.hashCode();
   }

   public String toString() {
      return this.time;
   }
}
